# System Monitor

This is a _minimal_ conversion of the Frontera Sysmon snippet to a Django CMS plugin.

> There is a functionally more advanced plugin, [bitbucket:rochaa/tacc-sysmon](https://bitbucket.org/rochaa/tacc-sysmon), which allows:
>
> - server-side requests (Python) instead of client-side requests (JavaScript)
> - multi-system tables

## To Do

- [GH-295](https://github.com/TACC/Core-CMS/issues/295)
